Documentation
¶
Index ¶
- Constants
- func NewEvaluationHandler(svc EvaluationHandler, opts ...connect.HandlerOption) (string, http.Handler)
- type EvaluationClient
- type EvaluationHandler
- type UnimplementedEvaluationHandler
- func (UnimplementedEvaluationHandler) StartEvaluation(context.Context, *connect.Request[evaluation.StartEvaluationRequest]) (*connect.Response[evaluation.StartEvaluationResponse], error)
- func (UnimplementedEvaluationHandler) StopEvaluation(context.Context, *connect.Request[evaluation.StopEvaluationRequest]) (*connect.Response[evaluation.StopEvaluationResponse], error)
Constants ¶
const ( // EvaluationStartEvaluationProcedure is the fully-qualified name of the Evaluation's // StartEvaluation RPC. EvaluationStartEvaluationProcedure = "/confirmate.evaluation.v1.Evaluation/StartEvaluation" // EvaluationStopEvaluationProcedure is the fully-qualified name of the Evaluation's StopEvaluation // RPC. EvaluationStopEvaluationProcedure = "/confirmate.evaluation.v1.Evaluation/StopEvaluation" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// EvaluationName is the fully-qualified name of the Evaluation service.
EvaluationName = "confirmate.evaluation.v1.Evaluation"
)
Variables ¶
This section is empty.
Functions ¶
func NewEvaluationHandler ¶
func NewEvaluationHandler(svc EvaluationHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewEvaluationHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type EvaluationClient ¶
type EvaluationClient interface {
// StartEvaluation evaluates periodically all assessment results based on a given audit scope id. Part of the public API, also exposed as REST.
StartEvaluation(context.Context, *connect.Request[evaluation.StartEvaluationRequest]) (*connect.Response[evaluation.StartEvaluationResponse], error)
// StopEvaluation stops the evaluation for the given audit scope.
// Part of the public API, also exposed as REST.
StopEvaluation(context.Context, *connect.Request[evaluation.StopEvaluationRequest]) (*connect.Response[evaluation.StopEvaluationResponse], error)
}
EvaluationClient is a client for the confirmate.evaluation.v1.Evaluation service.
func NewEvaluationClient ¶
func NewEvaluationClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) EvaluationClient
NewEvaluationClient constructs a client for the confirmate.evaluation.v1.Evaluation service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type EvaluationHandler ¶
type EvaluationHandler interface {
// StartEvaluation evaluates periodically all assessment results based on a given audit scope id. Part of the public API, also exposed as REST.
StartEvaluation(context.Context, *connect.Request[evaluation.StartEvaluationRequest]) (*connect.Response[evaluation.StartEvaluationResponse], error)
// StopEvaluation stops the evaluation for the given audit scope.
// Part of the public API, also exposed as REST.
StopEvaluation(context.Context, *connect.Request[evaluation.StopEvaluationRequest]) (*connect.Response[evaluation.StopEvaluationResponse], error)
}
EvaluationHandler is an implementation of the confirmate.evaluation.v1.Evaluation service.
type UnimplementedEvaluationHandler ¶
type UnimplementedEvaluationHandler struct{}
UnimplementedEvaluationHandler returns CodeUnimplemented from all methods.
func (UnimplementedEvaluationHandler) StartEvaluation ¶
func (UnimplementedEvaluationHandler) StartEvaluation(context.Context, *connect.Request[evaluation.StartEvaluationRequest]) (*connect.Response[evaluation.StartEvaluationResponse], error)
func (UnimplementedEvaluationHandler) StopEvaluation ¶
func (UnimplementedEvaluationHandler) StopEvaluation(context.Context, *connect.Request[evaluation.StopEvaluationRequest]) (*connect.Response[evaluation.StopEvaluationResponse], error)